@@ -37,18 +37,18 @@ def init():
     """Downloads the required Nltk packages"""
     nltk.download("punkt")
     nltk.download("averaged_perceptron_tagger")
-    os.system("python3 -m spacy download en")
-    os.system("python3 -m spacy download fr")
+    os.system("python3 -m spacy download en_core_web_sm")
+    os.system("python3 -m spacy download fr_core_news_sm")
 
 
 @cli.command()
 @click.option(
-    "--notion",
-    "-n",
+    "--knowledge",
+    "-k",
     type=click.Path(
         exists=True, file_okay=True, dir_okay=False, writable=True, readable=True
     ),
-    help="File containing the notions that are already defined.",
+    help="File containing the knowledges that are already defined.",
     required=True,
 )
 @click.option(
@@ -69,8 +69,8 @@ def init():
     "--scope/--no-scope",
     "-S/ ",
     default=False,
-    help="Print the scopes defined in the notion file and print \
-the possible meaning of those scope inferred by Knowledge Clustering.",
+    help="Print the scopes defined in the knowledge file and print \
+the possible meaning of those scope inferred by knowledge-clustering.",
 )
 @click.option(
     "--config-file",
@@ -79,12 +79,12 @@ the possible meaning of those scope inferred by Knowledge Clustering.",
     help=f"Specify the configuration file. By default the configuration file in the folder {CONFIG_DIR} \
 corresponding to your language is used.",
 )
-def cluster(notion, diagnose, scope, lang, config_file):
+def cluster(knowledge, diagnose, scope, lang, config_file):
     """
-    Edit a NOTION file using the knowledges present
+    Edit a KNOWLEDGE file using the knowledges present
     in a DIAGNOSE file.
     """
-    with open(notion, "r") as f:
+    with open(knowledge, "r") as f:
         document, known_knowledges = kltex.parse(f)
 
     if config_file == None:
@@ -118,9 +118,13 @@ def cluster(notion, diagnose, scope, lang, config_file):
         known_knowledges[bag_id][len_bags[bag_id] :]
         for bag_id in range(len_known_knowledges)
     ]
-    print(f"Found a solution by adding {len(new_knowledges)} new bag(s).")
+    print(
+        f"Found a solution by adding {len(new_knowledges)} new knowledge"
+        + ("(s)" if len(new_knowledges) >= 2 else "")
+        + "."
+    )
 
-    with fu.AtomicUpdate(notion) as f:
+    with fu.AtomicUpdate(knowledge) as f:
         kltex.writeDocument(f, document, updated_knowledges, new_knowledges)
 
 
@@ -135,32 +139,38 @@ def cluster(notion, diagnose, scope, lang, config_file):
     required=True,
 )
 @click.option(
-    "--notion",
-    "-n",
+    "--knowledge",
+    "-k",
     type=click.Path(
         exists=True, file_okay=True, dir_okay=False, writable=True, readable=True
     ),
-    help="File containing the notions that are already defined.",
+    help="File containing the knowledges that are already defined.",
     required=True,
 )
+@click.option(
+    "--column",
+    "-c",
+    is_flag=True,
+    help="When finding a match for a knowledge, precise between which columns (tabs count as 4 columns).",
+)
 @click.option(
     "--force",
     "-F",
     is_flag=True,
     help="Don't ask the user and always add quotes if a match is found.",
 )
-def addquotes(tex, notion, force):
+def addquotes(tex, knowledge, column, force):
     """
     Finds knowledges defined in NOTION that appear in TEX without quote symbols.
     Proposes to add (or add, if the force option is enabled) quotes around them.
     """
     with open(tex, "r") as f:
         tex_document = f.read()
-    with open(notion, "r") as f:
+    with open(knowledge, "r") as f:
         _, known_knowledges = kltex.parse(f)
     known_knowledges = [kl for bag in known_knowledges for kl in bag]
     tex_document_new = quotes.quote_maximal_substrings(
-        tex_document, known_knowledges, not force, False, 4
+        tex_document, known_knowledges, not force, column, 4
     )
     with fu.AtomicUpdate(tex) as f:
         f.write(tex_document_new)
